"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'pycrosskit'
__description__ = 'Cross Platform Toolkit for Windows and Linux in order to make variables and shortcuts easy'
__version__ = '1.0.4.1'
__author__ = 'Jiri Otoupal'
__author_email__ = 'jiri-otoupal@ips-database.eu'
__license__ = 'Apache 2.0'
__url__ = 'https://github.com/jiri-otoupal/py-cross-kit'
